{#table_dlg.title}

- {#table_dlg.general_tab}
- {#table_dlg.advanced_tab}

{#table_dlg.general_props}

{#table_dlg.cols} |  | {#table_dlg.rows} |
{#table_dlg.cellpadding} |  | {#table_dlg.cellspacing} |
{#table_dlg.align} |  | {#table_dlg.border} |
{#table_dlg.width} |  | {#table_dlg.height} |
{#class_name} |
{#table_dlg.caption} |

{#table_dlg.advanced_props}

{#table_dlg.id} |
{#table_dlg.summary} |
{#table_dlg.style} |
{#table_dlg.langcode} |
{#table_dlg.bgimage} |
{#table_dlg.frame} |
{#table_dlg.rules} |
{#table_dlg.langdir} |
{#table_dlg.bordercolor} |
{#table_dlg.bgcolor} |